package com.caimei365.user.controller;

import com.caimei365.user.idempotent.IpSave;
import com.caimei365.user.mapper.CmBrandBannerMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.BaikeProductDto;
import com.caimei365.user.model.dto.ShopArticleDto;
import com.caimei365.user.model.dto.ShopBannerDto;
import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.CmBrandBanner;
import com.caimei365.user.model.po.CmBrandFiles;
import com.caimei365.user.model.po.CmBrandLanding;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.CmBrandBannerService;
import com.caimei365.user.service.CmBrandFilesService;
import com.caimei365.user.service.CmBrandLandingService;
import com.caimei365.user.service.ShopService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author : Kaick
 * @date : 2023/5/31
 */
@Api(tags = "供应商落地页")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/landing")
public class CmBrandLandingApi {

    private final CmBrandBannerService cmBrandBannerService;

    private final CmBrandLandingService cmBrandLandingService;

    private final CmBrandFilesService cmBrandFilesService;

    /**
     * 查询供应商落地页资料
     *
     * @return source 1PC端,2小程序
     * @return Map(userPo, clubPo)
     * @return banner > banner管理
     * @return landing.type 1成功案例,2视频列表，3文章列表
     */
    @ApiOperation("查询供应商落地页资料")
    @GetMapping("/info")
    public ResponseJson<Map<String, Object>> getShopUserInfo(Integer source) {
        if(source==null){
            return ResponseJson.error("source异常", null);
        }
        CmBrandBanner cmBrandBanner = new CmBrandBanner().setType("2");
        CmBrandLanding landing = new CmBrandLanding().setType("1,2,3");
        if(source==1){
            cmBrandBanner.setPcStatus("1");
            landing.setPcStatus("1");
        }
        if(source==2){
            cmBrandBanner.setAppStatus("1");
            landing.setAppStatus("1");
        }
        HashMap<String, Object> map = new HashMap(2);
        List<CmBrandBanner> cmBrandBanners = cmBrandBannerService.selectCmBrandBannerList(cmBrandBanner);
        List<CmBrandLanding> cmBrandLandings = cmBrandLandingService.selectCmBrandLandingList(landing);
        cmBrandLandings.forEach(cmBrandLanding -> {
            CmBrandFiles cmBrandFiles = new CmBrandFiles();
            cmBrandFiles.setId(cmBrandLanding.getVideo());
            cmBrandFiles.setType("1");
            cmBrandLanding.setCmBrandFiles(cmBrandLanding.getVideo() == null ? null :
                    cmBrandFilesService.selectCmBrandFilesList(cmBrandFiles));
        });
        map.put("banner", cmBrandBanners);
        map.put("landing", cmBrandLandings);
        return ResponseJson.success(map);
    }
}
